<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */

if ( ! function_exists( 'corponess_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Corponess Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function corponess_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'corponess_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'corponess_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Corponess Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function corponess_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'corponess_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'corponess_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Corponess Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function corponess_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'corponess_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'corponess_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Corponess Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function corponess_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[slider_content_type]' )->value();
	return corponess_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[slider_content_type]' )->value();
	return corponess_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[slider_content_type]' )->value();
	return corponess_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if service section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[service_content_type]' )->value();
	return corponess_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[service_content_type]' )->value();
	return corponess_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[service_content_type]' )->value();
	return corponess_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is custom.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[about_content_type]' )->value();
	return corponess_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[about_content_type]' )->value();
	return corponess_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[about_content_type]' )->value();
	return corponess_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}/**
 * Check if project section is enabled.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_project_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[project_section_enable]' )->value() );
}

/**
 * Check if feature section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_feature_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[feature_section_enable]' )->value() );
}

/**
 * Check if feature section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_feature_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[feature_content_type]' )->value();
	return corponess_pro_is_feature_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if feature section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_feature_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[feature_content_type]' )->value();
	return corponess_pro_is_feature_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if feature section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_feature_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[feature_content_type]' )->value();
	return corponess_pro_is_feature_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[cta_content_type]' )->value();
	return corponess_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[cta_content_type]' )->value();
	return corponess_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[cta_content_type]' )->value();
	return corponess_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if client section is enabled.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_client_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[client_section_enable]' )->value() );
}

/**
 * Check if client section content type is category.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_client_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[client_content_type]' )->value();
	return corponess_pro_is_client_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if client section content type is page.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_client_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[client_content_type]' )->value();
	return corponess_pro_is_client_section_enable( $control ) && ( 'page' == $content_type );
}

/*
 * Check if client section content type is post.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
 
function corponess_pro_is_client_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[client_content_type]' )->value();
	return corponess_pro_is_client_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if client section content type is recent.
 *
 * @since Corponess Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_client_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[client_content_type]' )->value();
	return corponess_pro_is_client_section_enable( $control ) && ( 'custom' == $content_type );
}

function corponess_pro_is_client_section_hr_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[client_content_type]' )->value();
	return corponess_pro_is_client_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[team_content_type]' )->value();
	return corponess_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[team_content_type]' )->value();
	return corponess_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[team_content_type]' )->value();
	return corponess_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[testimonial_content_type]' )->value();
	return corponess_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[testimonial_content_type]' )->value();
	return corponess_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[testimonial_content_type]' )->value();
	return corponess_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[blog_content_type]' )->value();
	return corponess_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[blog_content_type]' )->value();
	return corponess_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[blog_content_type]' )->value();
	return corponess_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[blog_content_type]' )->value();
	return corponess_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if subscribe section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_subscribe_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[subscribe_section_enable]' )->value() );
}







/**
 * Check if popular section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_popular_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[popular_content_type]' )->value();
	return corponess_pro_is_popular_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_popular_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[popular_content_type]' )->value();
	return corponess_pro_is_popular_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_popular_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[popular_content_type]' )->value();
	return corponess_pro_is_popular_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if featured section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[featured_content_type]' )->value();
	return corponess_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[featured_content_type]' )->value();
	return corponess_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[featured_content_type]' )->value();
	return corponess_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}



/**
 * Check if recent section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[recent_section_enable]' )->value() );
}

/**
 * Check if recent section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[recent_content_type]' )->value();
	return corponess_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_recent_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[recent_content_type]' )->value();
	return corponess_pro_is_recent_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_recent_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[recent_content_type]' )->value();
	return corponess_pro_is_recent_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if most_view section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_most_view_section_enable( $control ) {
	return ( $control->manager->get_setting( 'corponess_pro_theme_options[most_view_section_enable]' )->value() );
}

/**
 * Check if most_view section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_most_view_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[most_view_content_type]' )->value();
	return corponess_pro_is_most_view_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_view section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_most_view_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[most_view_content_type]' )->value();
	return corponess_pro_is_most_view_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_view section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function corponess_pro_is_most_view_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'corponess_pro_theme_options[most_view_content_type]' )->value();
	return corponess_pro_is_most_view_section_enable( $control ) && ( 'post' == $content_type );
}