<?php
/**
 * Client Section options
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */
// Add client Collection section
$wp_customize->add_section( 'corponess_pro_client_section', array(
    'title'             => esc_html__( 'Partner','corponess-pro' ),
    'description'       => esc_html__( 'Partner Section options.', 'corponess-pro' ),
    'panel'             => 'corponess_pro_front_page_panel',
) );

// client content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[client_section_enable]', array(
    'default'           =>  $options['client_section_enable'],
    'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[client_section_enable]', array(
    'label'             => esc_html__( 'Partner Section Enable', 'corponess-pro' ),
    'section'           => 'corponess_pro_client_section',
    'on_off_label'      => corponess_pro_switch_options(),
) ) );

// client content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[client_column_layout]', array(
    'default'           => $options['client_column_layout'],
    'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[client_column_layout]', array(
    'label'             => esc_html__( 'Column Layout', 'corponess-pro' ),
    'section'           => 'corponess_pro_client_section',
    'type'              => 'select',
    'active_callback'   => 'corponess_pro_is_client_section_enable',
    'choices'           => array( 
        'col-3'         => esc_html__( '3 Column', 'corponess-pro' ),
        'col-4'         => esc_html__( '4 Column', 'corponess-pro' ),
    ),
) );

$wp_customize->add_setting( 'corponess_pro_theme_options[client_image]', array(
    'sanitize_callback' => 'corponess_pro_sanitize_image',
    'default'           => $options['client_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'corponess_pro_theme_options[client_image]',
        array(
        'label'             => esc_html__( 'Client Image', 'corponess-pro' ),
        'description'       => sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corponess-pro' ), 1351, 546 ),
        'section'           => 'corponess_pro_client_section',
        'active_callback'   => 'corponess_pro_is_client_section_enable',
) ) );

// client title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[client_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['client_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[client_title]', array(
    'label'             => esc_html__( 'Title', 'corponess-pro' ),
    'section'           => 'corponess_pro_client_section',
    'active_callback'   => 'corponess_pro_is_client_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[client_title]', array(
        'selector'            => '#our-partners .section-header h2',
        'settings'            => 'corponess_pro_theme_options[client_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'corponess_pro_client_title_partial',
    ) );
}

// client sub title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[client_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['client_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[client_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'corponess-pro' ),
    'section'           => 'corponess_pro_client_section',
    'active_callback'   => 'corponess_pro_is_client_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[client_sub_title]', array(
        'selector'            => '#our-partners .section-header p',
        'settings'            => 'corponess_pro_theme_options[client_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'corponess_pro_client_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'corponess_pro_theme_options[client_count]', array(
    'default'           => $options['client_count'],
    'sanitize_callback' => 'corponess_pro_sanitize_number_range',
    'validate_callback' => 'corponess_pro_validate_client_count',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[client_count]', array(
    'label'             => esc_html__( 'Number of partner', 'corponess-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'corponess-pro' ),
    'section'           => 'corponess_pro_client_section',
    'active_callback'   => 'corponess_pro_is_client_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 10,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'corponess_pro_theme_options[client_content_type]', array(
    'default'           => $options['client_content_type'],
    'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[client_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'corponess-pro' ),
    'section'           => 'corponess_pro_client_section',
    'type'              => 'select',
    'active_callback'   => 'corponess_pro_is_client_section_enable',
    'choices'           => array( 
        'page'          => esc_html__( 'Page', 'corponess-pro' ),
        'post'          => esc_html__( 'Post', 'corponess-pro' ),
        'category'          => esc_html__( 'Category', 'corponess-pro' ),
        'custom'        => esc_html__( 'Custom', 'corponess-pro' ),
    ),
) );

for ($i=1; $i <= $options['client_count'] ; $i++) :
    // client pages drop down chooser control and setting
    $wp_customize->add_setting( 'corponess_pro_theme_options[client_content_page_' . $i . ']', array(
        'sanitize_callback' => 'corponess_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[client_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'corponess-pro' ), $i ),
        'section'           => 'corponess_pro_client_section',
        'choices'           => corponess_pro_page_choices(),
        'active_callback'   => 'corponess_pro_is_client_section_content_page_enable',
    ) ) );

    // client posts drop down chooser control and setting
    $wp_customize->add_setting( 'corponess_pro_theme_options[client_content_post_' . $i . ']', array(
        'sanitize_callback' => 'corponess_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[client_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'corponess-pro' ), $i ),
        'section'           => 'corponess_pro_client_section',
        'choices'           => corponess_pro_post_choices(),
        'active_callback'   => 'corponess_pro_is_client_section_content_post_enable',
    ) ) );

    $wp_customize->add_setting( 'corponess_pro_theme_options[client_image_' . $i . ']', array(
        'sanitize_callback' => 'corponess_pro_sanitize_image',
    ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'corponess_pro_theme_options[client_image_' . $i . ']',
            array(
            'label'             => sprintf( esc_html__( 'Partner Logo %d', 'corponess-pro' ), $i ),
            'section'           => 'corponess_pro_client_section',
            'active_callback'   => 'corponess_pro_is_client_section_content_custom_enable',
    ) ) );

    $wp_customize->add_setting( 'corponess_pro_theme_options[client_url_' . $i . ']', array(
        'sanitize_callback' => 'esc_url_raw',
    ) );

    $wp_customize->add_control( 'corponess_pro_theme_options[client_url_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Client Url %d', 'corponess-pro' ), $i ),
        'section'           => 'corponess_pro_client_section',
        'active_callback'   => 'corponess_pro_is_client_section_content_custom_enable',
        'type'              => 'url',
    ) );


    $wp_customize->add_setting( 'corponess_pro_theme_options[client_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Corponess_Pro_Customize_Horizontal_Line( $wp_customize, 'corponess_pro_theme_options[client_hr_'. $i .']',
        array(
            'section'           => 'corponess_pro_client_section',
            'active_callback'   => 'corponess_pro_is_client_section_hr_enable',
            'type'            => 'hr'
    ) ) );

endfor;

$wp_customize->add_setting(  'corponess_pro_theme_options[client_content_category]', array(
    'sanitize_callback' => 'corponess_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Corponess_Pro_Dropdown_Taxonomies_Control( $wp_customize,'corponess_pro_theme_options[client_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'corponess-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'corponess-pro' ),
    'section'           => 'corponess_pro_client_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'corponess_pro_is_client_section_content_category_enable'
) ) );



        