<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */

// Add Call To Action section
$wp_customize->add_section( 'corponess_pro_cta_section', array(
    'title'             => esc_html__( 'Call To Action','corponess-pro' ),
    'description'       => esc_html__( 'Call To Action Section options.', 'corponess-pro' ),
    'panel'             => 'corponess_pro_front_page_panel',
) );

// Call To Action content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[cta_section_enable]', array(
    'default'           =>  $options['cta_section_enable'],
    'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[cta_section_enable]', array(
    'label'             => esc_html__( 'Call To Action Section Enable', 'corponess-pro' ),
    'section'           => 'corponess_pro_cta_section',
    'on_off_label'      => corponess_pro_switch_options(),
) ) );

// Call To Action content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[cta_content_type]', array(
    'default'           => $options['cta_content_type'],
    'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[cta_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'corponess-pro' ),
    'section'           => 'corponess_pro_cta_section',
    'type'              => 'select',
    'active_callback'   => 'corponess_pro_is_cta_section_enable',
    'choices'           => array( 
        'page'      => esc_html__( 'Page', 'corponess-pro' ),
        'post'      => esc_html__( 'Post', 'corponess-pro' ),
        'custom'    => esc_html__( 'Custom', 'corponess-pro' ),
    ),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[cta_content_page]', array(
    'sanitize_callback' => 'corponess_pro_sanitize_page',
) );

$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[cta_content_page]', array(
    'label'             => esc_html__( 'Select Page', 'corponess-pro' ),
    'section'           => 'corponess_pro_cta_section',
    'choices'           => corponess_pro_page_choices(),
    'active_callback'   => 'corponess_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[cta_content_post]', array(
    'sanitize_callback' => 'corponess_pro_sanitize_page',
) );

$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[cta_content_post]', array(
    'label'             => esc_html__( 'Select Post', 'corponess-pro' ),
    'section'           => 'corponess_pro_cta_section',
    'choices'           => corponess_pro_post_choices(),
    'active_callback'   => 'corponess_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[cta_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['cta_title'],
) );

$wp_customize->add_control( 'corponess_pro_theme_options[cta_title]', array(
    'label'             => esc_html__( 'Title', 'corponess-pro' ),
    'section'           => 'corponess_pro_cta_section',
    'active_callback'   => 'corponess_pro_is_cta_section_content_custom_enable',
    'type'              => 'text',
) );

// cta title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[cta_content]', array(
    'sanitize_callback' => 'wp_kses_post',
    'default'           => $options['cta_content'],
) );

$wp_customize->add_control( 'corponess_pro_theme_options[cta_content]', array(
    'label'             => esc_html__( 'Content', 'corponess-pro' ),
    'section'           => 'corponess_pro_cta_section',
    'active_callback'   => 'corponess_pro_is_cta_section_content_custom_enable',
    'type'              => 'textarea',
) );


// video link setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[video_link]', array(
    'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[video_link]', array(
    'label'             => esc_html__( 'Video Link', 'corponess-pro' ),
    'section'           => 'corponess_pro_cta_section',
    'active_callback'   => 'corponess_pro_is_cta_section_enable',
    'type'              => 'url',
) );

// cta image setting and control.
$wp_customize->add_setting( 'corponess_pro_theme_options[cta_image]', array(
    'sanitize_callback' => 'corponess_pro_sanitize_image',
    'default'           =>  $options['cta_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'corponess_pro_theme_options[cta_image]',
    array(
    'label'             => esc_html__( 'Background Image ', 'corponess-pro' ), 
    'description'       => sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corponess-pro' ), 700, 600 ),
    'section'           => 'corponess_pro_cta_section',
    'active_callback'   => 'corponess_pro_is_cta_section_enable',
) ) );

