<?php
/**
 * project Section options
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */

// Add project section
$wp_customize->add_section( 'corponess_pro_project_section', array(
	'title'             => esc_html__( 'Project','corponess-pro' ),
	'description'       => esc_html__( 'Project Section options.', 'corponess-pro' ),
	'panel'             => 'corponess_pro_front_page_panel',
) );

// project content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[project_section_enable]', array(
	'default'			=> 	$options['project_section_enable'],
	'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[project_section_enable]', array(
	'label'             => esc_html__( 'Pourse Section Enable', 'corponess-pro' ),
	'section'           => 'corponess_pro_project_section',
	'on_off_label' 		=> corponess_pro_switch_options(),
) ) );

// project title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[project_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['project_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[project_title]', array(
	'label'           	=> esc_html__( 'Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_project_section',
	'active_callback' 	=> 'corponess_pro_is_project_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[project_title]', array(
		'selector'            => '#our-projects .section-header h2',
		'settings'            => 'corponess_pro_theme_options[project_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_project_title_partial',
    ) );
}

// project sub title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[project_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['project_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[project_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_project_section',
	'active_callback' 	=> 'corponess_pro_is_project_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[project_sub_title]', array(
		'selector'            => '#our-projects .section-header p',
		'settings'            => 'corponess_pro_theme_options[project_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_project_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'corponess_pro_theme_options[project_category_exclude]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Corponess_Pro_Dropdown_Category_Control( $wp_customize,'corponess_pro_theme_options[project_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'corponess-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'corponess-pro' ),
	'section'           => 'corponess_pro_project_section',
	'type'              => 'dropdown-categories',
) ) );

// project btn title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[project_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['project_btn_title'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'corponess_pro_theme_options[project_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_project_section',
	'active_callback' 	=> 'corponess_pro_is_project_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[project_btn_title]', array(
		'selector'            => '#our-projects .view-all a',
		'settings'            => 'corponess_pro_theme_options[project_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_project_btn_title_partial',
    ) );
}


// project btn link setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[project_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[project_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_project_section',
	'active_callback' 	=> 'corponess_pro_is_project_section_enable',
	'type'				=> 'url',
) );
