<?php
/**
 * subscribe Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add subscribe section
$wp_customize->add_section( 'corponess_pro_subscribe_section', array(
	'title'             => esc_html__( 'Subscribe','corponess-pro' ),
	'description'       => esc_html__( 'Subscribe Section options.', 'corponess-pro' ),
	'panel'             => 'corponess_pro_front_page_panel',
) );

// subscribe content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[subscribe_section_enable]', array(
	'default'			=> 	$options['subscribe_section_enable'],
	'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[subscribe_section_enable]', array(
	'label'             => esc_html__( 'Subscribe Section Enable', 'corponess-pro' ),
	'section'           => 'corponess_pro_subscribe_section',
	'on_off_label' 		=> corponess_pro_switch_options(),
) ) );

// subscribe title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[subscribe_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[subscribe_title]', array(
	'label'           	=> esc_html__( 'Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_subscribe_section',
	'active_callback' 	=> 'corponess_pro_is_subscribe_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[subscribe_title]', array(
		'selector'            => '#subscribe-section header h2',
		'settings'            => 'corponess_pro_theme_options[subscribe_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_subscribe_title_partial',
    ) );
}

// subscribe sub title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[subscribe_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[subscribe_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_subscribe_section',
	'active_callback' 	=> 'corponess_pro_is_subscribe_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[subscribe_sub_title]', array(
		'selector'            => '#subscribe-section .entry-content p',
		'settings'            => 'corponess_pro_theme_options[subscribe_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_subscribe_sub_title_partial',
    ) );
}


$wp_customize->add_setting( 'corponess_pro_theme_options[subscribe_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[subscribe_btn_label]', array(
	'label'           	=> esc_html__( 'subscribe Link Label', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_subscribe_section',
	'active_callback' 	=> 'corponess_pro_is_subscribe_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[subscribe_btn_label]', array(
		'selector'            => '#subscribe-section #subscribe-submit button',
		'settings'            => 'corponess_pro_theme_options[subscribe_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_subscribe_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'corponess_pro_theme_options[subscribe_image]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'corponess_pro_theme_options[subscribe_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'corponess-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corponess-pro' ), 1350, 600 ),
		'section'     		=> 'corponess_pro_subscribe_section',
		'active_callback'	=> 'corponess_pro_is_subscribe_section_enable',
) ) );
