<?php
/**
 * featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */
if ( ! function_exists( 'corponess_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Corponess Pro 1.0.0
    */
    function corponess_pro_add_featured_section() {
    	$options = corponess_pro_get_theme_options();
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'corponess_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get featured section details
        $section_details = array();
        $section_details = apply_filters( 'corponess_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured section now.
        corponess_pro_render_featured_section( $section_details );
    }
endif;

if ( ! function_exists( 'corponess_pro_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since Corponess Pro 1.0.0
    * @param array $input featured section details.
    */
    function corponess_pro_get_featured_section_details( $input ) {
        $options = corponess_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 3;
        
        $content = array();
        switch ( $featured_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['id']     = get_the_ID();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = corponess_pro_trim_content( 30 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_ID(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured section content details.
add_filter( 'corponess_pro_filter_featured_section_details', 'corponess_pro_get_featured_section_details' );


if ( ! function_exists( 'corponess_pro_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since Corponess Pro 1.0.0
   *
   */
   function corponess_pro_render_featured_section( $content_details = array() ) {
        $options = corponess_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="corponess_pro_featured_section">
            <div id="magazine-featured-posts">
                <div class="wrapper">
                    <?php if ( !empty( $options['featured_title'] ) ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['featured_title'] ) ; ?></h2>
                        </div><!-- .section-header -->

                    <?php endif ?>
                   
                    <div class="col-4 clear">
                        <?php foreach ($content_details as $content): ?>
                            <article>
                                <div class="featured-post-item">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $content['image'] ) ?>">
                                         <?php corponess_pro_posted_on( $content['id'] ) ?>
                                    </div><!-- .featured-image -->
                                    <div class="entry-container">
                                        <?php the_category( '', '', $content['id']) ?>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>"><?php echo esc_html( $content['title'] ) ?></a></h2>
                                        </header>   
                                         <div class="entry-content">
                                            <?php echo esc_html( $content['excerpt'] ) ?>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-post-item -->
                            </article>
                        <?php endforeach ?>
                    </div><!-- .col-4 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-featured-posts -->    
        </div>
                            
    <?php }
endif;