<?php
/**
 * popular section
 *
 * This is the template for the content of popular section
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */
if ( ! function_exists( 'corponess_pro_add_popular_section' ) ) :
    /**
    * Add popular section
    *
    *@since Corponess Pro 1.0.0
    */
    function corponess_pro_add_popular_section() {
    	$options = corponess_pro_get_theme_options();
        // Check if popular is enabled on frontpage
        $popular_enable = apply_filters( 'corponess_pro_section_status', true, 'popular_section_enable' );

        if ( true !== $popular_enable ) {
            return false;
        }
        // Get popular section details
        $section_details = array();
        $section_details = apply_filters( 'corponess_pro_filter_popular_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular section now.
        corponess_pro_render_popular_section( $section_details );
    }
endif;

if ( ! function_exists( 'corponess_pro_get_popular_section_details' ) ) :
    /**
    * popular section details.
    *
    * @since Corponess Pro 1.0.0
    * @param array $input popular section details.
    */
    function corponess_pro_get_popular_section_details( $input ) {
        $options = corponess_pro_get_theme_options();

        // Content type.
        $popular_content_type  = $options['popular_content_type'];
        $popular_count = ! empty( $options['popular_count'] ) ? $options['popular_count'] : 3;
        
        $content = array();
        switch ( $popular_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_count; $i++ ) {
                    if ( ! empty( $options['popular_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_count; $i++ ) {
                    if ( ! empty( $options['popular_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_content_category'] ) ? $options['popular_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['id']     = get_the_ID();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = corponess_pro_trim_content( 30 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_ID(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular section content details.
add_filter( 'corponess_pro_filter_popular_section_details', 'corponess_pro_get_popular_section_details' );


if ( ! function_exists( 'corponess_pro_render_popular_section' ) ) :
  /**
   * Start popular section
   *
   * @return string popular content
   * @since Corponess Pro 1.0.0
   *
   */
   function corponess_pro_render_popular_section( $content_details = array() ) {
        $options = corponess_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="corponess_pro_popular_section">
            <div id="magazine-popular-posts">
                <div class="wrapper">
                    <div class="col-3 clear">
                       <?php foreach ($content_details as $content): ?>
                            <article>
                                <div class="popular-post-item">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $content['image'] ) ?>">
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <?php the_category( '', '', $content['id']) ?>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>"><?php echo esc_html( $content['title'] ) ?></a></h2>
                                        </header>   
                                        <?php corponess_pro_posted_on( $content['id'] ) ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .popular-post-item -->
                            </article>
                       <?php endforeach ?>
                        
                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-popular-posts -->
        </div>
       
                       
    <?php }
endif;