<?php
/**
 * projects section
 *
 * This is the template for the content of project section
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */
if ( ! function_exists( 'corponess_pro_add_project_section' ) ) :
    /**
    * Add project section
    *
    *@since Corponess Pro 1.0.0
    */
    function corponess_pro_add_project_section() {
    	$options = corponess_pro_get_theme_options();
        // Check if project is enabled on frontpage
        $project_enable = apply_filters( 'corponess_pro_section_status', true, 'project_section_enable' );

        if ( true !== $project_enable ) {
            return false;
        }
        // Get project section details
        $section_details = array();
        $section_details = apply_filters( 'corponess_pro_filter_project_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render project section now.
        corponess_pro_render_project_section( $section_details );
    }
endif;

if ( ! function_exists( 'corponess_pro_get_project_section_details' ) ) :
    /**
    * project section details.
    *
    * @since Corponess Pro 1.0.0
    * @param array $input project section details.
    */
    function corponess_pro_get_project_section_details( $input ) {
        $options = corponess_pro_get_theme_options();

        $cats = ! empty( $options['project_category_exclude'] ) ? $options['project_category_exclude'] : array();
        $content = array();
        $i = 0;
        foreach ( $cats as $cat_id ) :
            $content[$i] = array();
            $args = array(
                'post_type'         => 'post',
                'cat'               => absint( $cat_id ),
                'ignore_sticky_posts'   => true,
                );                    


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post[$i]['title']     = get_the_title();
                    $page_post[$i]['url']       = get_the_permalink();
                    $page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content[$i], $page_post[$i] );
                endwhile;
            endif;
            wp_reset_postdata();
            $i++;
        endforeach;

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// project section content details.
add_filter( 'corponess_pro_filter_project_section_details', 'corponess_pro_get_project_section_details' );


if ( ! function_exists( 'corponess_pro_render_project_section' ) ) :
  /**
   * Start project section
   *
   * @return string project content
   * @since Corponess Pro 1.0.0
   *
   */
   function corponess_pro_render_project_section( $content_details = array() ) {
        $options = corponess_pro_get_theme_options();
        $cats = ! empty( $options['project_category_exclude'] ) ? $options['project_category_exclude'] : array();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="corponess_pro_project_section">
            <div id="our-projects" class="relative page-section same-background">
                <div class="wrapper title-wrapper">
                    <div class="section-header">
                        <h2 class="section-title">Our Successful Project</h2>
                        <p class="section-subtitle">Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start and terrified.</p>
                    </div><!-- .section-header -->

                    <ul class="tabs">
                        <?php $i = 1 ; foreach ( $cats as $cat ): ?>
                            <li>
                                <a href="#" data-tab="<?php echo absint( $cat ) ; ?>" class="<?php echo $i == 1 ? 'active' : '' ; ?>">
                                    <?php echo get_cat_name( $cat ); ?>                                        
                                </a>
                            </li>
                        <?php $i++ ; endforeach ?>
                    </ul><!-- .tabs -->
                </div><!-- .wrapper -->
                <div class="wrapper tabs-wrapper">
                    <div class="section-content col-4">
                        <?php $i = 0 ; foreach ( $content_details as $content_detail ): ?>
                            <div id="<?php echo absint( $cats[$i] ) ; ?>" class="tab-content clear <?php echo $i == 0 ? 'active' : '' ; ?>">
                                <?php foreach ( $content_detail as $content ): ?>
                                    <article>
                                        <div class="overlay"></div>
                                        <div class="featured-image">
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                                <img src="<?php echo esc_url( $content['image'] ) ; ?>" alt="<?php echo esc_attr( $content['title'] ) ; ?>" >
                                            </a>
                                        </div><!-- .featured-image -->

                                        <header class="entry-header">
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="more-link"><i class="fa fa-link"></i></a>
                                            <h2 class="entry-title">
                                                <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                                    <?php echo esc_html( $content['title'] ) ; ?>
                                                </a>
                                            </h2>
                                        </header>
                                    </article>
                                <?php endforeach ?>
                            </div><!-- .tab-content -->
                        <?php $i++ ; endforeach ?>                        
                    </div><!-- .section-content -->
                    <?php if ( ! empty( $options['project_btn_title'] ) && ! empty( $options['project_btn_link'] ) ): ?>
                        <div class="view-all">
                            <a href="<?php echo esc_url( $options['project_btn_link'] ) ; ?>" class="btn">
                                <?php echo esc_html( $options['project_btn_title'] ) ; ?>
                            </a>
                        </div><!-- .view-all -->
                    <?php endif ?>                    
                </div><!-- .wrapper -->
            </div><!-- #projects-section -->
        </div>
        

    <?php }
endif;