<?php
/**
 * subscribe section
 *
 * This is the template for the content of subscribe section
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */
if ( ! function_exists( 'corponess_pro_add_subscribe_section' ) ) :
    /**
    * Add subscribe section
    *
    *@since Corponess Pro 1.0.0
    */
    function corponess_pro_add_subscribe_section() {
        $options = corponess_pro_get_theme_options();
        // Check if subscribe is enabled on frontpage
        $subscribe_enable = apply_filters( 'corponess_pro_section_status', true, 'subscribe_section_enable' );

        if ( true !== $subscribe_enable ) {
            return false;
        }

        // Render subscribe section now.
        corponess_pro_render_subscribe_section();
    }
endif;

if ( ! function_exists( 'corponess_pro_render_subscribe_section' ) ) :
  /**
   * Start subscribe section
   *
   * @return string subscribe content
   * @since Corponess Pro 1.0.0
   *
   */
   function corponess_pro_render_subscribe_section() {
        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }
        $options = corponess_pro_get_theme_options();
        $image = ! empty( $options['subscribe_image'] ) ? $options['subscribe_image'] : ''; 

        ?>
        <div id="corponess_pro_subscribe_section">
            <div id="subscribe-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ) ; ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( ! empty( $options['subscribe_title'] ) ): ?>
                        <header class="entry-header">
                            <h2 class="entry-title">
                                <?php echo esc_html( $options['subscribe_title'] ) ; ?>
                            </h2>
                        </header>
                    <?php endif ;
                   
                    if ( ! empty( $options['subscribe_sub_title'] ) ): ?>
                        <div class="entry-content">
                            <p>
                                <?php echo esc_html( $options['subscribe_sub_title'] ) ; ?>
                            </p>
                        </div><!-- .entry-content -->
                    <?php endif ;
                    
                        $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $options['subscribe_btn_label'] ) . '" show_subscribers_total="0"]';
                        echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                     ?>
                </div><!-- .wrapper -->
            </div><!-- #subscribe-section -->
        </div>
        
    <?php }
endif;
